==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/zh_CN.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "存储暂时不可用",
    "Storage invalid" : "存储空间无效",
    "Unknown error" : "未知错误",
    "All files" : "全部文件",
    "Recent" : "最近",
    "Favorites" : "收藏",
    "File could not be found" : "文件未找到",
    "Move or copy" : "移动或者复制",
    "Download" : "下载",
    "Delete" : "删除",
    "Home" : "首页",
    "Close" : "关闭",
    "Could not create folder \"{dir}\"" : "无法创建文件夹 \"{dir}\"",
    "This will stop your current uploads." : "这会终止您当前的上传。",
    "Upload cancelled." : "上传已取消。",
    "Processing files …" : "文件处理中…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "无法上传文件 {filename}，因为它是一个目录或者是大小为 0 的空文件",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空间不足，您上传的文件大小为 {size1} ，但可用空间仅剩 {size2}",
    "Target folder \"{dir}\" does not exist any more" : "目标目录 \"{dir}\" 不存在",
    "Not enough free space" : "可用空间不足",
    "An unknown error has occurred" : "发生了未知错误。",
    "Uploading …" : "上传中…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "不支持上传此项目",
    "Target folder does not exist any more" : "目标文件夹不存在",
    "Error when assembling chunks, status code {status}" : "组装块时发生错误，状态码 {status}",
    "Actions" : "操作",
    "Rename" : "重命名",
    "Copy" : "复制",
    "Choose target folder" : "选择目标文件夹",
    "Open" : "打开",
    "Disconnect storage" : "断开存储的连接",
    "Unshare" : "取消共享",
    "Could not load info for file \"{file}\"" : "无法加载文件 \"{file}\" 的信息",
    "Files" : "文件",
    "Details" : "详细信息",
    "Select" : "选择",
    "Pending" : "等待",
    "Unable to determine date" : "无法确定日期",
    "This operation is forbidden" : "操作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
    "Could not move \"{file}\", target exists" : "无法移动 \"{file}\"，目标已存在",
    "Could not move \"{file}\"" : "无法移动 \"{file}\"",
    "copy" : "复制",
    "Could not copy \"{file}\", target exists" : "无法复制“{file}”，目标已存在",
    "Could not copy \"{file}\"" : "不能复制 \"{文件}\"",
    "Copied {origin} inside {destination}" : "在 {destination} 内复制 {origin}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "在 {destination} 内复制 {origin} 和 {nbfiles} 其他文件",
    "{newName} already exists" : "{newName} 已经存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "无法重命名 \"{fileName}\"，此文件已经不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "文件夹 \"{dir}\" 中已经存在 \"{targetName}\"。请尝试其他的名称。",
    "Could not rename \"{fileName}\"" : "无法重命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "无法创建文件 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "无法创建文件 \"{file}\"，因为它已经存在",
    "Could not create folder \"{dir}\" because it already exists" : "无法创建文件夹 \"{dir}\"，因为它已经存在",
    "Error deleting file \"{fileName}\"." : "删除文件 \"{fileName}\" 时出错。",
    "No search results in other folders for {tag}{filter}{endtag}" : "在其它的文件夹里没有关于 {tag}{filter}{endtag} 的搜索结果",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "_%n folder_::_%n folders_" : ["%n 个文件夹"],
    "_%n file_::_%n files_" : ["%n 个文件"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包括 %n 个隐藏文件"],
    "You don’t have permission to upload or create files here" : "您没有权限在此上传或创建文件",
    "_Uploading %n file_::_Uploading %n files_" : ["上传 %n 个文件"],
    "New" : "新建",
    "Select file range" : "选择文件范围",
    "{used} of {quota} used" : "已使用 {used} / {quota}",
    "{used} used" : "{used} 已使用",
    "\"{name}\" is an invalid file name." : "\"{name}\" 是一个无效的文件名。",
    "File name cannot be empty." : "文件名不能为空。",
    "\"/\" is not allowed inside a file name." : "文件名不能包含“/”",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 不是允许的文件类型",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满，文件将无法更新或同步！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完（{usedSpacePercent}%）",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的存储空间即将用完（{usedSpacePercent}%）",
    "_matches '{filter}'_::_match '{filter}'_" : ["匹配 '{filter}'"],
    "View in folder" : "在文件夹中查看",
    "Copied!" : "已复制",
    "Copy direct link (only works for users who have access to this file/folder)" : "复制直接链接(仅适用于有权访问此文件/文件夹的用户)",
    "Path" : "路径",
    "_%n byte_::_%n bytes_" : ["%n 字节"],
    "Favorited" : "已收藏",
    "Favorite" : "收藏",
    "You can only favorite a single file or folder at a time" : "您一次只能收藏一个文件或文件夹",
    "New folder" : "新建文件夹",
    "Upload file" : "上传文件",
    "Not favorited" : "未收藏",
    "Remove from favorites" : "取消收藏",
    "Add to favorites" : "收藏",
    "An error occurred while trying to update the tags" : "更新标签时出错",
    "Added to favorites" : "已添加到收藏",
    "Removed from favorites" : "取消收藏",
    "You added {file} to your favorites" : "您已经添加 {file} 到您的收藏夹",
    "You removed {file} from your favorites" : "您已从收藏夹中删除 {file}",
    "File changes" : "文件发生变化",
    "Created by {user}" : "由 {user} 创建",
    "Changed by {user}" : "由 {user} 更改",
    "Deleted by {user}" : "由 {user} 删除",
    "Restored by {user}" : "由 {user} 恢复",
    "Renamed by {user}" : "由 {user} 重命名",
    "Moved by {user}" : "由 {user} 移动",
    "\"remote user\"" : "远程用户",
    "You created {file}" : "您创建了 {file}",
    "You created an encrypted file in {file}" : "您在 {file} 创建了一个加密文件",
    "{user} created {file}" : "{user} 创建了 {file}",
    "{user} created an encrypted file in {file}" : "{user} 在 {file} 中创建一个加密文件",
    "{file} was created in a public folder" : "{file} 被创建在公共文件夹",
    "You changed {file}" : "您更改了 {file}",
    "You changed an encrypted file in {file}" : "您在 {file} 更改了加密文件",
    "{user} changed {file}" : "{user} 更改了 {file}",
    "{user} changed an encrypted file in {file}" : "{user} 在 {file} 更改了加密文件",
    "You deleted {file}" : "您删除了{file}",
    "You deleted an encrypted file in {file}" : "您在 {file} 删除了加密文件",
    "{user} deleted {file}" : "{user} 删除了 {file}",
    "{user} deleted an encrypted file in {file}" : "{user} 在 {file} 删除了加密文件",
    "You restored {file}" : "您恢复了{file}",
    "{user} restored {file}" : "{user} 恢复了 {file}",
    "You renamed {oldfile} to {newfile}" : "您将 {oldfile} 改名为 {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} 将 {oldfile} 改名为 {newfile}",
    "You moved {oldfile} to {newfile}" : "您移动 {oldfile} 到 {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} 移动 {oldfile} 到 {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "文件已经添加或删除到您的 <strong>收藏夹</strong> 中",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "文件/文件夹已经 <strong>更改</strong> 或者 <strong>重命名</strong>",
    "A new file or folder has been <strong>created</strong>" : "新的文件/文件夹已经 <strong>创建</strong>",
    "A file or folder has been <strong>deleted</strong>" : "文件/文件夹已删除",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "仅限 <strong>收藏文件</strong>的创建和更改通知 <em>（仅限流）</em>",
    "A file or folder has been <strong>restored</strong>" : "文件/文件夹已恢复",
    "Unlimited" : "无限制",
    "Upload (max. %s)" : "上传 （最大 %s）",
    "File Management" : "文件管理",
    "%s of %s used" : "%s 已使用 (共 %s)",
    "%1$s%% of %2$s used" : "%2$s 中%1$s %% 已使用",
    "%s used" : "%s 已使用",
    "Settings" : "设置",
    "Show hidden files" : "显示隐藏文件",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "使用这个地址 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">通过 WebDAV 访问您的文件</a>",
    "Toggle grid view" : "切换网格视图",
    "No files in here" : "无文件",
    "Upload some content or sync with your devices!" : "上传或从您的设备中同步！",
    "No entries found in this folder" : "文件夹中无项目",
    "Select all" : "全部选择",
    "Upload too large" : "上传文件过大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "正在上传的文件超过了此服务器允许上传的最大容量限制",
    "No favorites yet" : "还没有“我喜欢的”",
    "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
    "Tags" : "标签",
    "Deleted files" : "已删除的文件",
    "Shares" : "共享",
    "Shared with others" : "与他人共享",
    "Shared with you" : "与您共享",
    "Shared by link" : "通过链接共享",
    "Deleted shares" : "已删除的共享",
    "Text file" : "文本文件",
    "New text file.txt" : "新建文本文件.txt",
    "Target folder" : "目标目录",
    "File handling" : "文件处理",
    "Maximum upload size" : "最大上传大小",
    "max. possible: " : "最大允许：",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "对于 PHP-FPM 这个值改变后可能需要 5 分钟才会生效。",
    "Missing permissions to edit from here." : "没有权限编辑。",
    "Cancel upload" : "取消上传",
    "%1$s of %2$s used" : "%1$s已用，总计%2$s"
},
"nplurals=1; plural=0;");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/zh_CN.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "存储暂时不可用",
    "Storage invalid" : "存储空间无效",
    "Unknown error" : "未知错误",
    "All files" : "全部文件",
    "Recent" : "最近",
    "Favorites" : "收藏",
    "File could not be found" : "文件未找到",
    "Move or copy" : "移动或者复制",
    "Download" : "下载",
    "Delete" : "删除",
    "Home" : "首页",
    "Close" : "关闭",
    "Could not create folder \"{dir}\"" : "无法创建文件夹 \"{dir}\"",
    "This will stop your current uploads." : "这会终止您当前的上传。",
    "Upload cancelled." : "上传已取消。",
    "Processing files …" : "文件处理中…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "无法上传文件 {filename}，因为它是一个目录或者是大小为 0 的空文件",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空间不足，您上传的文件大小为 {size1} ，但可用空间仅剩 {size2}",
    "Target folder \"{dir}\" does not exist any more" : "目标目录 \"{dir}\" 不存在",
    "Not enough free space" : "可用空间不足",
    "An unknown error has occurred" : "发生了未知错误。",
    "Uploading …" : "上传中…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "不支持上传此项目",
    "Target folder does not exist any more" : "目标文件夹不存在",
    "Error when assembling chunks, status code {status}" : "组装块时发生错误，状态码 {status}",
    "Actions" : "操作",
    "Rename" : "重命名",
    "Copy" : "复制",
    "Choose target folder" : "选择目标文件夹",
    "Open" : "打开",
    "Delete file" : "删除文件",
    "Delete folder" : "删除文件夹",
    "Disconnect storage" : "断开存储的连接",
    "Unshare" : "取消共享",
    "Could not load info for file \"{file}\"" : "无法加载文件 \"{file}\" 的信息",
    "Files" : "文件",
    "Details" : "详细信息",
    "Select" : "选择",
    "Pending" : "等待",
    "Unable to determine date" : "无法确定日期",
    "This operation is forbidden" : "操作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
    "Could not move \"{file}\", target exists" : "无法移动 \"{file}\"，目标已存在",
    "Could not move \"{file}\"" : "无法移动 \"{file}\"",
    "copy" : "复制",
    "Could not copy \"{file}\", target exists" : "无法复制“{file}”，目标已存在",
    "Could not copy \"{file}\"" : "不能复制 \"{文件}\"",
    "Copied {origin} inside {destination}" : "在 {destination} 内复制 {origin}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "在 {destination} 内复制 {origin} 和 {nbfiles} 其他文件",
    "{newName} already exists" : "{newName} 已经存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "无法重命名 \"{fileName}\"，此文件已经不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "文件夹 \"{dir}\" 中已经存在 \"{targetName}\"。请尝试其他的名称。",
    "Could not rename \"{fileName}\"" : "无法重命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "无法创建文件 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "无法创建文件 \"{file}\"，因为它已经存在",
    "Could not create folder \"{dir}\" because it already exists" : "无法创建文件夹 \"{dir}\"，因为它已经存在",
    "Error deleting file \"{fileName}\"." : "删除文件 \"{fileName}\" 时出错。",
    "No search results in other folders for {tag}{filter}{endtag}" : "在其它的文件夹里没有关于 {tag}{filter}{endtag} 的搜索结果",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "_%n folder_::_%n folders_" : ["%n 个文件夹"],
    "_%n file_::_%n files_" : ["%n 个文件"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包括 %n 个隐藏文件"],
    "You don’t have permission to upload or create files here" : "您没有权限在此上传或创建文件",
    "_Uploading %n file_::_Uploading %n files_" : ["上传 %n 个文件"],
    "New" : "新建",
    "Select file range" : "选择文件范围",
    "{used} of {quota} used" : "已使用 {used} / {quota}",
    "{used} used" : "已使用 {used} 存储空间",
    "\"{name}\" is an invalid file name." : "\"{name}\" 是一个无效的文件名。",
    "File name cannot be empty." : "文件名不能为空。",
    "\"/\" is not allowed inside a file name." : "文件名不能包含“/”",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 不是允许的文件类型",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满，文件将无法更新或同步！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完（{usedSpacePercent}%）",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的存储空间即将用完（{usedSpacePercent}%）",
    "_matches '{filter}'_::_match '{filter}'_" : ["匹配 '{filter}'"],
    "View in folder" : "在文件夹中查看",
    "Copied!" : "已复制",
    "Copy direct link (only works for users who have access to this file/folder)" : "复制直接链接(仅适用于有权访问此文件/文件夹的用户)",
    "Path" : "路径",
    "_%n byte_::_%n bytes_" : ["%n 字节"],
    "Favorited" : "已收藏",
    "Favorite" : "收藏",
    "You can only favorite a single file or folder at a time" : "您一次只能收藏一个文件或文件夹",
    "New folder" : "新建文件夹",
    "Upload file" : "上传文件",
    "Not favorited" : "未收藏",
    "Remove from favorites" : "取消收藏",
    "Add to favorites" : "收藏",
    "An error occurred while trying to update the tags" : "更新标签时出错",
    "Added to favorites" : "已添加到收藏",
    "Removed from favorites" : "取消收藏",
    "You added {file} to your favorites" : "您已经添加 {file} 到您的收藏夹",
    "You removed {file} from your favorites" : "您已从收藏夹中删除 {file}",
    "File changes" : "文件发生变化",
    "Created by {user}" : "由 {user} 创建",
    "Changed by {user}" : "由 {user} 更改",
    "Deleted by {user}" : "由 {user} 删除",
    "Restored by {user}" : "由 {user} 恢复",
    "Renamed by {user}" : "由 {user} 重命名",
    "Moved by {user}" : "由 {user} 移动",
    "\"remote user\"" : "远程用户",
    "You created {file}" : "您创建了 {file}",
    "You created an encrypted file in {file}" : "您在 {file} 创建了一个加密文件",
    "{user} created {file}" : "{user} 创建了 {file}",
    "{user} created an encrypted file in {file}" : "{user} 在 {file} 中创建一个加密文件",
    "{file} was created in a public folder" : "{file} 被创建在公共文件夹",
    "You changed {file}" : "您更改了 {file}",
    "You changed an encrypted file in {file}" : "您在 {file} 更改了加密文件",
    "{user} changed {file}" : "{user} 更改了 {file}",
    "{user} changed an encrypted file in {file}" : "{user} 在 {file} 更改了加密文件",
    "You deleted {file}" : "您删除了{file}",
    "You deleted an encrypted file in {file}" : "您在 {file} 删除了加密文件",
    "{user} deleted {file}" : "{user} 删除了 {file}",
    "{user} deleted an encrypted file in {file}" : "{user} 在 {file} 删除了加密文件",
    "You restored {file}" : "您恢复了{file}",
    "{user} restored {file}" : "{user} 恢复了 {file}",
    "You renamed {oldfile} to {newfile}" : "您将 {oldfile} 改名为 {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} 将 {oldfile} 改名为 {newfile}",
    "You moved {oldfile} to {newfile}" : "您移动 {oldfile} 到 {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} 移动 {oldfile} 到 {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "文件已经添加或删除到您的 <strong>收藏夹</strong> 中",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "文件/文件夹已经 <strong>更改</strong> 或者 <strong>重命名</strong>",
    "A new file or folder has been <strong>created</strong>" : "新的文件/文件夹已经 <strong>创建</strong>",
    "A file or folder has been <strong>deleted</strong>" : "文件/文件夹已删除",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "仅限 <strong>收藏文件</strong>的创建和更改通知 <em>（仅限流）</em>",
    "A file or folder has been <strong>restored</strong>" : "文件/文件夹已恢复",
    "Unlimited" : "无限制",
    "Upload (max. %s)" : "上传 （最大 %s）",
    "Accept" : "接受",
    "Reject" : "拒绝",
    "Incoming ownership transfer from {user}" : "来自{user}的所有权转移",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "您要接受{path}吗？\n\n注意：接受之后的转移过程可能长达1小时。",
    "Ownership transfer failed" : "所有权转移失败",
    "Your ownership transfer of {path} to {user} failed." : "您的{path}向{user}的所有权转移失败。",
    "The ownership transfer of {path} from {user} failed." : "来自{user}的{path}的所有权转移失败。",
    "Ownership transfer done" : "所有权转移完成",
    "Your ownership transfer of {path} to {user} has completed." : "您的{path}向{user}的所有权转移已完成。",
    "The ownership transfer of {path} from {user} has completed." : "来自{user}的{path}的所有权转移已完成。",
    "File Management" : "文件管理",
    "Transfer ownership of a file or folder" : "转移文件或文件夹的所有权",
    "Choose file or folder to transfer" : "选择要转移的文件或文件夹",
    "Change" : "变更",
    "New owner" : "新的拥有者",
    "Search users" : "搜索用户",
    "Choose a file or folder to transfer" : "选择要转移的文件或文件夹",
    "Transfer" : "转移",
    "Transfer {path} to {userid}" : "转移{path}到{userid}",
    "Invalid path selected" : "选择的路径无效",
    "Ownership transfer request sent" : "所有权转移请求已发送",
    "Error while loading the file data" : "加载文件数据时出错",
    "Unable to change the favourite state of the file" : "无法更改文件的收藏状态",
    "%s used" : "%s 已使用",
    "%s%% of %s used" : "%s中%s%%已使用",
    "%1$s of %2$s used" : "%1$s已用，总计%2$s",
    "Settings" : "设置",
    "Show hidden files" : "显示隐藏文件",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "使用这个地址 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">通过 WebDAV 访问您的文件</a>",
    "Toggle grid view" : "切换网格视图",
    "No files in here" : "无文件",
    "Upload some content or sync with your devices!" : "上传或从您的设备中同步！",
    "No entries found in this folder" : "文件夹中无项目",
    "Select all" : "全部选择",
    "Upload too large" : "上传文件过大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "正在上传的文件超过了此服务器允许上传的最大容量限制",
    "No favorites yet" : "还没有“我喜欢的”",
    "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
    "Tags" : "标签",
    "Deleted files" : "已删除的文件",
    "Shares" : "共享",
    "Shared with others" : "与他人共享",
    "Shared with you" : "与您共享",
    "Shared by link" : "通过链接共享",
    "Deleted shares" : "已删除的共享",
    "Text file" : "文本文件",
    "New text file.txt" : "新建文本文件.txt",
    "File handling" : "文件处理",
    "Maximum upload size" : "最大上传大小",
    "max. possible: " : "最大允许：",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "对于 PHP-FPM 这个值改变后可能需要 5 分钟才会生效。",
    "Missing permissions to edit from here." : "没有权限编辑。",
    "Cancel upload" : "取消上传",
    "%s of %s used" : "%s 已使用 (共 %s)",
    "%1$s%% of %2$s used" : "%2$s 中%1$s %% 已使用"
},
"nplurals=1; plural=0;");
